skhubness.neighbors.HNSW
========================

.. currentmodule:: skhubness.neighbors

.. autoclass:: HNSW

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HNSW.__init__
      ~HNSW.fit
      ~HNSW.kneighbors
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HNSW.valid_metrics
   
   